import {
  geoGraticule,
  geoNaturalEarth1,
  geoPath,
  line,
  select,
} from 'd3';

const projection = geoNaturalEarth1();
const path = geoPath(projection);
const graticule = geoGraticule();

export const Marks = ({
  worldAtlas: { land, interiors },
  cities,
  sizeScale,
  sizeValue
}) => {
  return (
    <g className="marks">
      <path
        className="sphere"
        d={path({ type: 'Sphere' })}
      />
      <path className="graticules" d={path(graticule())} />
      {land.features.map((feature) => (
        <g>
          <path className="land" d={path(feature)}>
            <title>{feature.properties.name}</title>
          </path>
        </g>
      ))}
      <path className="interiors" d={path(interiors)} />
      {cities.map((d) => {
        const [x, y] = projection([d.lng, d.lat]);
        return (
          <circle
            cx={x}
            cy={y}
            r={sizeScale(sizeValue(d))}
            fill="white"
            opacity="0.5"
          >
            <title>{`${d.city}, ${d.country}\nLng: ${d.lng} Lat: ${d.lat}`}</title>
          </circle>
        );
      })}
    </g>
  );
};
